Fix some misspelled words.

Signed-off-by: Weiwei Jia <[email protected]>
---
 lib/backend.py |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lib/backend.py b/lib/backend.py
index 7063aa5..6904615 100644
--- a/lib/backend.py
+++ b/lib/backend.py
@@ -3191,7 +3191,7 @@ def BlockdevRename(devlist):
 def _TransformFileStorageDir(fs_dir):
   """Checks whether given file_storage_dir is valid.
 
   Checks wheter the given fs_dir is within the cluster-wide default
   file_storage_dir or the shared_file_storage_dir, which are stored in
   SimpleStore. Only paths under those directories are allowed.
 
@@ -3213,7 +3213,7 @@ def CreateFileStorageDir(file_storage_dir):
   @param file_storage_dir: directory to create
 
   @rtype: tuple
-  @return: tuple with first element a boolean indicating wheter dir
+  @return: tuple with first element a boolean indicating whether dir
       creation was successful or not
 
   """
@@ -3191,7 +3191,7 @@ def BlockdevRename(devlist):
   """Checks whether given file_storage_dir is valid.
 
-  Checks wheter the given fs_dir is within the cluster-wide default
+  Checks whether the given fs_dir is within the cluster-wide default
   file_storage_dir or the shared_file_storage_dir, which are stored in
   SimpleStore. Only paths under those directories are allowed.
-- 
1.7.10.4

Reply via email to